# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).

## [Unreleased](https://github.com/python-social-auth/social-app-django-mongoengine/commits/master)

## [0.2.0](https://github.com/python-social-auth/social-app-django/releases/tag/0.2.0) - 2016-12-28

### Changed
- Fixed setup.py requirements loading by defining dependency links

## [0.1.0](https://github.com/python-social-auth/social-app-django/releases/tag/0.1.0) - 2016-12-28

### Changed
- Fixed django-mongoengine dependency (port of [#1027](https://github.com/omab/python-social-auth/pull/1027)
  by erezarnon)

## [0.0.1](https://github.com/python-social-auth/social-app-django/releases/tag/0.0.1) - 2016-11-27

### Chaged
- Split from the monolitic [python-social-auth](https://github.com/omab/python-social-auth)
  codebase
